@@ -36,14 +36,15 @@ use File::Temp;
 use Carp;
 
 our %defaults;
+use constant	MAX_SLURP_SIZE => 16 * 1024;	# CSV files <= than this size are read into memory
 
 =head1 VERSION
 
-Version 0.03
+Version 0.04
 
 =cut
 
-our $VERSION = '0.03';
+our $VERSION = '0.04';
 
 =head1 SYNOPSIS
 
@@ -86,7 +87,9 @@ Set some class level defaults.
 
     MyPackageName::Database::init(directory => '../databases');
 
-See the documentation for new() to see what variables can be set
+See the documentation for new() to see what variables can be set.
+
+Returns a refernce to a hash of the current values.
 
 =cut
 
@@ -97,7 +100,9 @@ sub init {
 	# $defaults->{'logger'} ||= $args{'logger'};
 	# $defaults->{'cache'} ||= $args{'cache'};
 	# $defaults->{'cache_duration'} ||= $args{'cache_duration'};
-	%defaults = %args;
+	%defaults = (%args, %defaults);
+
+	return \%defaults;
 }
 
 =head2 new
@@ -152,7 +157,8 @@ sub new {
 		# table => $args{'table'},	# The name of the file containing the table, defaults to the class name
 		# no_entry => $args{'no_entry'} || 0,
 	# }, $class;
-	return bless { %args, %defaults, no_entry => 0 }, $class;
+	# Reseen keys take precendence, so defaults come first
+	return bless { no_entry => 0, %defaults, %args }, $class;
 }
 
 =head2	set_logger
@@ -317,32 +323,34 @@ sub _open {
 			# $self->{'data'} = Text::CSV::Slurp->load(file => $slurp_file, %options);
 
 			# FIXME: Text::xSV::Slurp can't cope well with quotes in field contents
-			require Text::xSV::Slurp;
-			Text::xSV::Slurp->import();
+			if((-s $slurp_file) <= MAX_SLURP_SIZE) {
+				require Text::xSV::Slurp;
+				Text::xSV::Slurp->import();
 
-			my @data = @{xsv_slurp(
-				shape => 'aoh',
-				text_csv => {
-					sep_char => $sep_char,
-					allow_loose_quotes => 1,
-					blank_is_undef => 1,
-					empty_is_undef => 1,
-					binary => 1,
-					escape_char => '\\',
-				},
-				# string => \join('', grep(!/^\s*(#|$)/, <DATA>))
-				file => $slurp_file
-			)};
+				my @data = @{xsv_slurp(
+					shape => 'aoh',
+					text_csv => {
+						sep_char => $sep_char,
+						allow_loose_quotes => 1,
+						blank_is_undef => 1,
+						empty_is_undef => 1,
+						binary => 1,
+						escape_char => '\\',
+					},
+					# string => \join('', grep(!/^\s*(#|$)/, <DATA>))
+					file => $slurp_file
+				)};
 
-			# Ignore blank lines or lines starting with # in the CSV file
-			unless($self->{no_entry}) {
-				@data = grep { $_->{'entry'} !~ /^\s*#/ } grep { defined($_->{'entry'}) } @data;
-			}
-			# $self->{'data'} = @data;
-			my $i = 0;
-			$self->{'data'} = ();
-			foreach my $d(@data) {
-				$self->{'data'}[$i++] = $d;
+				# Ignore blank lines or lines starting with # in the CSV file
+				unless($self->{no_entry}) {
+					@data = grep { $_->{'entry'} !~ /^\s*#/ } grep { defined($_->{'entry'}) } @data;
+				}
+				# $self->{'data'} = @data;
+				my $i = 0;
+				$self->{'data'} = ();
+				foreach my $d(@data) {
+					$self->{'data'}[$i++] = $d;
+				}
 			}
 			$self->{'type'} = 'CSV';
 		} else {
